@@ -1,5 +1,8 @@
 package Software::Catalog;
 
+our $DATE = '2015-09-04'; # DATE
+our $VERSION = '0.05'; # VERSION
+
 use 5.010001;
 use strict;
 use warnings;
@@ -13,10 +16,13 @@ our @EXPORT_OK = qw(
                        list_software
                );
 
-our $VERSION = '0.04'; # VERSION
-
 our %SPEC;
 
+$SPEC{':package'} = {
+    v => 1.1,
+    summary => 'Software catalog',
+};
+
 # XXX import catalog from software-catalog
 # (https://github.com/sharyanto/software-catalog)
 my @software = (
@@ -146,7 +152,7 @@ Software::Catalog - Software catalog
 
 =head1 VERSION
 
-This document describes version 0.04 of Software::Catalog (from Perl distribution Software-Catalog), released on 2014-08-22.
+This document describes version 0.05 of Software::Catalog (from Perl distribution Software-Catalog), released on 2015-09-04.
 
 =head1 SYNOPSIS
 
@@ -180,8 +186,6 @@ Arguments ('*' denotes required arguments):
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -191,7 +195,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
+Return value:  (any)
 
 
 =head2 list_software(%args) -> [status, msg, result, meta]
@@ -208,7 +212,7 @@ Arguments ('*' denotes required arguments):
 
 Only return records where the 'debian_names' field equals specified value.
 
-=item * B<debian_names.has> => I<array>
+=item * B<debian_names.has> => I<array[str]>
 
 Only return records where the 'debian_names' field is an array/list which contains specified value.
 
@@ -220,7 +224,7 @@ Only return records where the 'debian_names' field equals specified value.
 
 Only return records where the 'debian_names' field does not equal specified value.
 
-=item * B<debian_names.lacks> => I<array>
+=item * B<debian_names.lacks> => I<array[str]>
 
 Only return records where the 'debian_names' field is an array/list which does not contain specified value.
 
@@ -230,7 +234,7 @@ Return array of full records instead of just ID fields.
 
 By default, only the key (ID) field is returned per result entry.
 
-=item * B<fields> => I<array>
+=item * B<fields> => I<array[str]>
 
 Select fields to return.
 
@@ -242,7 +246,7 @@ Only return records where the 'id' field equals specified value.
 
 Only return records where the 'id' field contains specified text.
 
-=item * B<id.in> => I<array>
+=item * B<id.in> => I<array[str]>
 
 Only return records where the 'id' field is in the specified values.
 
@@ -266,7 +270,7 @@ Only return records where the 'id' field is greater than or equal to specified v
 
 Only return records where the 'id' field does not contain specified text.
 
-=item * B<id.not_in> => I<array>
+=item * B<id.not_in> => I<array[str]>
 
 Only return records where the 'id' field is not in the specified values.
 
@@ -278,7 +282,7 @@ Only return records where the 'id' field is less than specified value.
 
 Only return records where the 'id' field is greater than specified value.
 
-=item * B<q> => I<str>
+=item * B<query> => I<str>
 
 Search.
 
@@ -305,7 +309,7 @@ specify descending order instead of the default ascending.
 
 Only return records where the 'tags' field equals specified value.
 
-=item * B<tags.has> => I<array>
+=item * B<tags.has> => I<array[str]>
 
 Only return records where the 'tags' field is an array/list which contains specified value.
 
@@ -317,7 +321,7 @@ Only return records where the 'tags' field equals specified value.
 
 Only return records where the 'tags' field does not equal specified value.
 
-=item * B<tags.lacks> => I<array>
+=item * B<tags.lacks> => I<array[str]>
 
 Only return records where the 'tags' field is an array/list which does not contain specified value.
 
@@ -331,8 +335,6 @@ as list/array (field value, field value, ...).
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -342,7 +344,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
+Return value:  (any)
 
 =head1 STATUS
 
@@ -362,7 +364,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Software-C
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Software-Catalog>.
+Source repository is at L<https://github.com/perlancar/perl-Software-Catalog>.
 
 =head1 BUGS
 
@@ -374,11 +376,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
